@@ -4,7 +4,7 @@ from .errors import (SignatureBodyMismatchError, InvalidSignatureError, InvalidA
                      AuthError, InvalidMessageError, InvalidIntrospectionError,
                      InterfaceNotFoundError, SignalDisabledError, InvalidBusNameError,
                      InvalidObjectPathError, InvalidInterfaceNameError, InvalidMemberNameError,
-                     DBusError)
+                     NameNotFoundError, DBusError)
 from . import introspection
 from .message import Message
 from .message_bus import MessageBus
